syntax = "proto3";
package ubii.dataStructure;

message Vector3 {
    double x = 1;
    double y = 2;
    double z = 3;
}

message Vector3List {
    repeated ubii.dataStructure.Vector3 elements = 1;
}